<?php

namespace Drupal\contextual_filter_referer;

use Symfony\Component\HttpFoundation\RequestStack;

/**
 * Represents the current path for the referring request making the AJAX call.
 */
class RefererPathStack {

  /**
   * The request stack.
   *
   * @var \Symfony\Component\HttpFoundation\RequestStack
   */
  protected $requestStack;

  /**
   * Current request.
   *
   * @var \Symfony\Component\HttpFoundation\Request|null
   */
  protected $currentRequest;

  /**
   * Constructs a new CurrentPathStack instance.
   *
   * @param \Symfony\Component\HttpFoundation\RequestStack $request_stack
   *   The request stack.
   */
  public function __construct(RequestStack $request_stack) {
    $this->requestStack = $request_stack;
    $this->currentRequest = $this->requestStack->getCurrentRequest();
  }

  /**
   * Returns the path of the referring request.
   *
   * @return string
   *   Returns the path, without leading slashes.
   */
  public function getRefererPath() {
    // Get the referer from the request headers.
    $referer = $GLOBALS['request']->headers->get('referer');

    // Trim the base path and query params.
    $path = str_replace($this->currentRequest->getSchemeAndHttpHost(), '', $referer);
    $array = explode('?', $path);
    return reset($array);
  }

}
